@@ -67,7 +67,7 @@ import time
 from datetime import datetime as dt
 
 
-__version__ = "2.1.4"
+__version__ = "2.1.8"
 
 
 def calculate_date(
@@ -242,15 +242,6 @@ def get_run_details(
             headers=headers
         ).json()
 
-        # Ensure data is within range, or break out of the loop if not.
-        if (
-            calculate_time(
-                raw_response["data"][0]["attributes"]["status-timestamps"][
-                    "planning-at"]
-            ) > calculate_date(end_date)
-        ):
-            break
-
         try:
 
             # Add data from current page to the full list.
@@ -285,13 +276,20 @@ def get_run_details(
             print("Skipping run due to missing attribute(s).")
         
          # Ensure data is within range, or break out of the loop if not.
-        if (
-            calculate_time(
-                raw_response["data"][-1]["attributes"]["status-timestamps"][
-                    f"{raw_response['data'][-1]['attributes']['status'].replace('_', '-')}"
-                    "-at"]
-            ) < calculate_date(start_date)
-        ):
+        try:
+
+            if (
+                calculate_time(
+                    raw_response["data"][-1]["attributes"]["status-timestamps"][
+                        f"{raw_response['data'][-1]['attributes']['status'].replace('_', '-')}"
+                        "-at"]
+                ) < calculate_date(start_date)
+            ):
+                break
+        
+        except IndexError:
+
+            print("No runs to process. This Workspace might use a local backend execution.")
             break
 
         # Check next page for loop and stop if there's no more.
@@ -531,7 +529,7 @@ def main():
         "-V",
         "--version",
         action="version",
-        version="%(prog)s 2.1.4"
+        version=f"{__file__} {__version__}"
     )
     myparser.add_argument(
         "-o",
